@@ -8,14 +8,12 @@
  */
 
 /* .Call calls */
-extern SEXP breaks_to_interval(SEXP, SEXP);
 extern SEXP cut_ages(SEXP, SEXP, SEXP);
 extern SEXP aggregate_age_counts(SEXP, SEXP, SEXP);
 extern SEXP split_interval_counts(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP reaggregate_interval_counts(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"breaks_to_interval",  (DL_FUNC) &breaks_to_interval, 2},
     {"cut_ages",  (DL_FUNC) &cut_ages, 3},
     {"aggregate_age_counts",  (DL_FUNC) &aggregate_age_counts, 3},
     {"split_interval_counts", (DL_FUNC) &split_interval_counts, 5},
